@@ -36,7 +36,7 @@ class ImageGenerator(
         )
         self.clip_model = self.clip_model.eval()
 
-        self.clip_input_img_size = self.clip_model.visual.input_resolution
+        self.clip_input_img_size = 224
 
         self.clip_norm_trans = torchvision.transforms.Normalize(
             (0.48145466, 0.4578275, 0.40821073),
