@@ -144,7 +144,7 @@ class TamingDecoder(ImageGenerator):
         return img_rec
 
     @staticmethod
-    def get_random_z(
+    def get_random_latent(
         target_img_height,
         target_img_width,
         batch_size=1,
@@ -176,6 +176,25 @@ class TamingDecoder(ImageGenerator):
         else:
             return loss, x_rec
 
+    def get_latent_from_image(
+        self,
+        img: PIL.Image,
+    ):
+        assert type(img) == PIL.Image, "image needs to be a PIL.Image"
+
+        img = img.convert('RGB')
+
+        img_tensor = torch.tensor(np.asarray(img)).to(
+            self.device).float()[None, :]
+        img_tensor = (img_tensor / 255.) * 2 - 1
+        img_tensor = img_tensor.permute(0, 3, 1, 2)
+
+        z, _, [_, _, _indices] = self.vqgan_model.encode(img_tensor)
+
+        z = z.to(self.device)
+
+        return z
+
     def generate_from_prompt(
         self,
         prompt: str,
@@ -253,7 +272,7 @@ class TamingDecoder(ImageGenerator):
             # img_z_logits = z.detach().clone()
 
         else:
-            z_logits = self.get_random_z(
+            z_logits = self.get_random_latent(
                 target_img_height=target_img_size,
                 target_img_width=target_img_size,
                 batch_size=batch_size,
